# -*- coding: utf-8 -*-
# this file is generated by gen_kdata_schema function, dont't change it
from sqlalchemy.ext.declarative import declarative_base

from zvt.contract.register import register_schema
from zvt_ccxt.domain.quotes import CoinKdataCommon

KdataBase = declarative_base()


class Coin5mKdata(KdataBase, CoinKdataCommon):
    __tablename__ = 'coin_5m_kdata'


register_schema(providers=['ccxt'], db_name='coin_5m_kdata', schema_base=KdataBase)

__all__ = ['Coin5mKdata']
