# -*- coding: utf-8 -*-
# this file is generated by gen_kdata_schema function, dont't change it
from zvt_ccxt.domain.quotes.coin.coin_tick_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_1m_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_5m_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_15m_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_30m_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_1h_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_4h_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_1d_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_1wk_kdata import *
from zvt_ccxt.domain.quotes.coin.coin_1mon_kdata import *